
eth-abi-tool
============

Ethereum Contract ABI Utility


.. image:: https://img.shields.io/github/license/rstms/eth_abi_tool
   :target: https://img.shields.io/github/license/rstms/eth_abi_tool
   :alt: Image



.. image:: https://img.shields.io/pypi/v/eth_abi_tool.svg
   :target: https://img.shields.io/pypi/v/eth_abi_tool.svg
   :alt: Image



.. image:: https://circleci.com/gh/rstms/eth_abi_tool/tree/master.svg?style=shield
   :target: https://circleci.com/gh/rstms/eth_abi_tool/tree/master.svg?style=shield
   :alt: Image



.. image:: https://readthedocs.org/projects/eth-abi-tool/badge/?version=latest
   :target: https://readthedocs.org/projects/eth-abi-tool/badge/?version=latest
   :alt: Image



.. image:: https://pyup.io/repos/github/rstms/eth_abi_tool/shield.svg
   :target: https://pyup.io/repos/github/rstms/eth_abi_tool/shield.svg
   :alt: Image


Use blockchain explorer API (currently only etherscan) to query ABI data for a verified contract.


* A CLI interface is provided as well as a python object.
* Includes rate-limiting for use with the various Etherscan account types.


* Free software: MIT license
* Documentation: https://eth-abi-tool.readthedocs.io.

Credits
-------

This package was created with Cookiecutter and ``rstms/cookiecutter-python-cli``\ , a fork of the ``audreyr/cookiecutter-pypackage`` project template.

`audreyr/cookiecutter <https://github.com/audreyr/cookiecutter>`_
`audreyr/cookiecutter-pypackage <https://github.com/audreyr/cookiecutter-pypackage>`_
`rstms/cookiecutter-python-cli <https://github.com/rstms/cookiecutter-python-cli>`_

CLI
---
